X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/f8415019d4edc1cd4f310adb256e6656e85bfe75..8d111632f51a23e6991306cc006dc936d362ab9e:/dwm.h?ds=inline

diff --git a/dwm.h b/dwm.h
index 2ec0bf7..f94ec8a 100644
--- a/dwm.h
+++ b/dwm.h
@@ -24,9 +24,8 @@
  *
  * Keys and tagging rules are organized as arrays and defined in the config.h
  * file. These arrays are kept static in event.o and tag.o respectively,
  * because no other part of dwm needs access to them.  The current mode is
  * represented by the arrange() function pointer, which wether points to
  * dofloat() or dotile(). 
  *
  * To understand everything else, start reading main.c:main().
  */
@@ -42,28 +41,6 @@ enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 
-typedef union {
-	const char *cmd;
-	int i;
-} Arg; /* argument type */
-
-typedef struct {
-	int ascent;
-	int descent;
-	int height;
-	XFontSet set;
-	XFontStruct *xfont;
-} Fnt;
-
-typedef struct {
-	int x, y, w, h;
-	unsigned long norm[ColLast];
-	unsigned long sel[ColLast];
-	Drawable drawable;
-	Fnt font;
-	GC gc;
-} DC; /* draw context */
-
 typedef struct Client Client;
 struct Client {
 	char name[256];
@@ -73,7 +50,7 @@ struct Client {
 	int minax, minay, maxax, maxay;
 	long flags; 
 	unsigned int border;
-	Bool isbanned, isfixed, isfloat, ismax;
+	Bool isbanned, isfixed, ismax, isuntiled;
 	Bool *tags;
 	Client *next;
 	Client *prev;
@@ -81,67 +58,92 @@ struct Client {
 	Window win;
 };
 
+typedef struct {
+	int x, y, w, h;
+	unsigned long norm[ColLast];
+	unsigned long sel[ColLast];
+	Drawable drawable;
+	GC gc;
+	struct {
+		int ascent;
+		int descent;
+		int height;
+		XFontSet set;
+		XFontStruct *xfont;
+	} font;
+} DC; /* draw context */
+
+typedef struct {
+	const char *symbol;
+	void (*arrange)(void);
+} Layout;
+
 extern const char *tags[];			/* all tags */
 extern char stext[256];				/* status text */
-extern int bh, bmw;				/* bar height, bar mode label width */
 extern int screen, sx, sy, sw, sh;		/* screen geometry */
 extern int wax, way, wah, waw;			/* windowarea geometry */
-extern unsigned int master, nmaster;		/* master percent, number of master clients */
+extern unsigned int bh, blw;			/* bar height, bar layout label width */
 extern unsigned int ntags, numlockmask;		/* number of tags, dynamic lock mask */
 extern void (*handler[LASTEvent])(XEvent *);	/* event handler */
-extern void (*arrange)(void);			/* arrange function, indicates mode  */
 extern Atom wmatom[WMLast], netatom[NetLast];
-extern Bool running, selscreen, *seltag;	/* seltag is array of Bool */
+extern Bool selscreen, *seltag;			/* seltag is array of Bool */
 extern Client *clients, *sel, *stack;		/* global client list and stack */
 extern Cursor cursor[CurLast];
 extern DC dc;					/* global draw context */
 extern Display *dpy;
+extern Layout *lt;
 extern Window root, barwin;
 
 /* client.c */
+extern void attach(Client *c);			/* attaches c to global client list */
 extern void configure(Client *c);		/* send synthetic configure event */
+extern void detach(Client *c);			/* detaches c from global client list */
 extern void focus(Client *c);			/* focus c, c may be NULL */
-extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
-extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
-extern void killclient(Arg *arg);		/* kill c nicely */
+extern void killclient(const char *arg);		/* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);	/* manage new client */
-Client *nexttiled(Client *c);			/* returns tiled successor of c */
 extern void resize(Client *c, int x, int y,
 		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
+extern void toggletiled(const char *arg);	/* toggles focused client between tiled/untiled state */
 extern void updatesizehints(Client *c);		/* update the size hint variables of c */
 extern void updatetitle(Client *c);		/* update the name of c */
 extern void unmanage(Client *c);		/* destroy c */
-extern void zoom(Arg *arg);			/* zooms the focused client to master area, arg is ignored */
+
+/* draw.c */
+extern void drawstatus(void);			/* draw the bar */
+extern void drawtext(const char *text, unsigned long col[ColLast]);	/* draw text */
+extern unsigned int textw(const char *text);	/* return the width of text in px*/
 
 /* event.c */
 extern void grabkeys(void);			/* grab all keys defined in config.h */
-extern void procevent(void);			/* process pending X events */
+
+/* layout.c */
+extern void focusclient(const char *arg);	/* focuses next(1)/previous(-1) visible client */
+extern void incmasterw(const char *arg);	/* increments the master width with arg's index value */
+extern void incnmaster(const char *arg);	/* increments nmaster with arg's index value */
+extern void initlayouts(void);			/* initialize layout array */
+extern Client *nexttiled(Client *c);		/* returns tiled successor of c */
+extern void restack(void);			/* restores z layers of all clients */
+extern void setlayout(const char *arg);		/* sets layout, -1 toggles */
+extern void togglemax(const char *arg);		/* toggles maximization of untiled client */
+extern void untile(void);			/* arranges all windows untiled */
+extern void zoom(const char *arg);		/* zooms the focused client to master area, arg is ignored */
 
 /* main.c */
-extern void drawstatus(void);			/* draw the bar */
-extern unsigned int textw(const char *text);	/* return the width of text in px*/
-extern void quit(Arg *arg);			/* quit dwm nicely */
+extern void quit(const char *arg);		/* quit dwm nicely */
 extern void sendevent(Window w, Atom a, long value);	/* send synthetic event to w */
 extern int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 
-/* screen.c */
-extern void compileregexps(void);		/* initialize regexps of rules defined in config.h */
-extern void dofloat(void);			/* arranges all windows floating */
-extern void dotile(void);			/* arranges all windows tiled */
-extern void incnmaster(Arg *arg);		/* increments nmaster with arg's index value */
+/* tag.c */
+extern void compileregs(void);			/* initialize regexps of rules defined in config.h */
 extern Bool isvisible(Client *c);		/* returns True if client is visible */
-extern void resizemaster(Arg *arg);		/* resizes the master percent with arg's index value */
-extern void restack(void);			/* restores z layers of all clients */
 extern void settags(Client *c, Client *trans);	/* sets tags of c */
-extern void tag(Arg *arg);			/* tags c with arg's index */
-extern void togglefloat(Arg *arg);		/* toggles focusesd client between floating/non-floating state */
-extern void togglemode(Arg *arg);		/* toggles global arrange function (dotile/dofloat) */
-extern void toggletag(Arg *arg);		/* toggles c tags with arg's index */
-extern void toggleview(Arg *arg);		/* toggles the tag with arg's index (in)visible */
-extern void view(Arg *arg);			/* views the tag with arg's index */
+extern void tag(const char *arg);		/* tags c with arg's index */
+extern void toggletag(const char *arg);		/* toggles c tags with arg's index */
+extern void toggleview(const char *arg);	/* toggles the tag with arg's index (in)visible */
+extern void view(const char *arg);		/* views the tag with arg's index */
 
 /* util.c */
 extern void *emallocz(unsigned int size);	/* allocates zero-initialized memory, exits on error */
 extern void eprint(const char *errstr, ...);	/* prints errstr and exits with 1 */
-extern void spawn(Arg *arg);			/* forks a new subprocess with to arg's cmd */
+extern void spawn(const char *arg);		/* forks a new subprocess with arg's cmd */
@@ -24,9 +24,8 @@
  * Keys and tagging rules are organized as arrays and defined in the config.h
  * file. These arrays are kept static in event.o and tag.o respectively,
- * because no other part of dwm needs access to them.  The current mode is
- * represented by the arrange() function pointer, which wether points to
- * dofloat() or dotile(). 
+ * because no other part of dwm needs access to them.  The current layout is
+ * represented by the lt pointer.
  *
  * To understand everything else, start reading main.c:main().